Entities

Struct Entities 

pub struct Entities { /* private fields */ }
Creates, destroys and recycles entities.

The most common reason to interact with Entities is to create or destroy an Entity.

let mut world = World::default();
let entities = world.get_entities_mut();
let ent = entities.create();
entities.destroy(ent);

Implementations

Source

impl Entities

pub fn alive_iter(&self) -> impl Iterator<Item = Entity> + '_

Return an iterator over all alive entities.

pub fn alive_len(&self) -> usize

Returns the number of entities that are currently alive.

pub fn create_many(&mut self, how_many: usize) -> Vec<usize>

Create many entities at once, returning a list of their ids.

An Entity can be made from its usize id using Entities::hydrate.

pub fn create(&mut self) -> Entity

Create one entity and return it.

pub fn destroy(&self, entity: Entity)

Lazily destroy an entity, removing its components and recycling it at the end of this tick.

NOTE:

Destroyed entities will have their components removed automatically during upkeep, which happens each World::tick_lazy.

pub fn destroy_all(&mut self)

Destroys all entities.

pub fn deleted_iter(&self) -> impl Iterator<Item = Entry<()>> + '_

Produce an iterator of deleted entities as entries.

This iterator should be filtered at the callsite for the latest changed entries since a stored iteration timestamp.

pub fn deleted_iter_of<T: 'static>( &self, ) -> impl Iterator<Item = Entry<()>> + '_

Produce an iterator of deleted entities that had a component of the given type, as entries.

This iterator should be filtered at the callsite for the latest changed entries since a stored iteration timestamp.

pub fn hydrate(&self, entity_id: usize) -> Option<Entity>

Hydrate an Entity from an id.

Returns None the entity with the given id does not exist, or has been destroyed.