LazyComponents

Struct LazyComponents 

pub struct LazyComponents(/* private fields */);
Add components lazily, at the time of your choosing.

Used in instances where you can’t apply changes to Components because of a borrow conflict (eg while iterating over a component query).

Implementations

Source

impl LazyComponents

pub fn insert_bundle<B: IsBundle + Send + Sync + 'static>( &mut self, entity_id: usize, bundle: B, )

Inserts the bundled components for the given entity.

pub fn insert_component<T: Send + Sync + 'static>( &mut self, entity_id: usize, component: T, )

Insert a single component for the given entity.

pub fn remove<B: IsBundle + 'static>(&mut self, entity_id: usize)

Remove all components of the given entity and return them as a typed bundle.

pub fn remove_component<T: Send + Sync + 'static>(&mut self, entity_id: usize)

Remove a single component from the given entity.

pub fn apply(self, components: &mut Components)

Apply changes.

Panics

Panics if the application of any changes panic.