View

Struct View 

pub struct View<T, G = SomeDefault>
where G: Gen<T>,
{ /* private fields */ }
Immutably borrowed resource that may be created by default.

Node functions wrap their parameters in View, ViewMut or Move.

View has two type parameters:

  • T - The type of the resource.
  • G - The method by which the resource can be generated if it doesn’t already exist. By default this is SomeDefault, which denotes creating the resource using its default instance. Another option is NoDefault which fails to generate the resource.
use moongraph::*;

let mut graph = Graph::default();
let default_number = graph.visit(|u: View<usize>| { *u }).map_err(|e| e.to_string());
assert_eq!(Ok(0), default_number);

let no_number = graph.visit(|f: View<f32, NoDefault>| *f);
assert!(no_number.is_err());