ViewMut

Struct ViewMut 

pub struct ViewMut<T, G = SomeDefault>
where G: Gen<T>,
{ /* private fields */ }
A mutably borrowed resource that may be created by default.

Node functions wrap their parameters in View, ViewMut or Move.

ViewMut has two type parameters:

  • T - The type of the resource.
  • G - The method by which the resource can be generated if it doesn’t already exist. By default this is SomeDefault, which denotes creating the resource using its default implementation. Another option is NoDefault which fails to generate the resource.
use moongraph::*;

let mut graph = Graph::default();
let default_number = graph.visit(|u: ViewMut<usize>| { *u }).map_err(|e| e.to_string());
assert_eq!(Ok(0), default_number);

let no_number = graph.visit(|f: ViewMut<f32, NoDefault>| *f);
assert!(no_number.is_err());