pub struct LazyComponents(/* private fields */);Expand description
Add components lazily, at the time of your choosing.
Used in instances where you can’t apply changes to Components because of a borrow conflict (eg while iterating over a component query).
Implementations
Sourceimpl LazyComponents
impl LazyComponents
Sourcepub fn insert_bundle<B: IsBundle + Send + Sync + 'static>(
&mut self,
entity_id: usize,
bundle: B,
)
pub fn insert_bundle<B: IsBundle + Send + Sync + 'static>( &mut self, entity_id: usize, bundle: B, )
Inserts the bundled components for the given entity.
Sourcepub fn insert_component<T: Send + Sync + 'static>(
&mut self,
entity_id: usize,
component: T,
)
pub fn insert_component<T: Send + Sync + 'static>( &mut self, entity_id: usize, component: T, )
Insert a single component for the given entity.
Sourcepub fn remove<B: IsBundle + 'static>(&mut self, entity_id: usize)
pub fn remove<B: IsBundle + 'static>(&mut self, entity_id: usize)
Remove all components of the given entity and return them as a typed bundle.
Sourcepub fn remove_component<T: Send + Sync + 'static>(&mut self, entity_id: usize)
pub fn remove_component<T: Send + Sync + 'static>(&mut self, entity_id: usize)
Remove a single component from the given entity.
Sourcepub fn apply(self, components: &mut Components)
pub fn apply(self, components: &mut Components)