pub struct ViewMut<T, G = SomeDefault>where
G: Gen<T>,{ /* private fields */ }Expand description
A mutably borrowed resource that may be created by default.
Node functions wrap their parameters in View, ViewMut or Move.
ViewMut has two type parameters:
T- The type of the resource.G- The method by which the resource can be generated if it doesn’t already exist. By default this isSomeDefault, which denotes creating the resource using its default implementation. Another option isNoDefaultwhich fails to generate the resource.
use moongraph::*;
let mut graph = Graph::default();
let default_number = graph.visit(|u: ViewMut<usize>| { *u }).map_err(|e| e.to_string());
assert_eq!(Ok(0), default_number);
let no_number = graph.visit(|f: ViewMut<f32, NoDefault>| *f);
assert!(no_number.is_err());Trait Implementations
Sourceimpl<T, G> Edges for ViewMut<T, G>
impl<T, G> Edges for ViewMut<T, G>
Sourceimpl<'a, T, G> IntoIterator for &'a ViewMut<T, G>
impl<'a, T, G> IntoIterator for &'a ViewMut<T, G>
Sourceimpl<'a, T, G> IntoIterator for &'a mut ViewMut<T, G>
impl<'a, T, G> IntoIterator for &'a mut ViewMut<T, G>
Sourceimpl<'a, T, G> IntoParallelIterator for &'a ViewMut<T, G>
impl<'a, T, G> IntoParallelIterator for &'a ViewMut<T, G>
Sourcetype Item = <&'a T as IntoParallelIterator>::Item
type Item = <&'a T as IntoParallelIterator>::Item
The type of item that the parallel iterator will produce.
Sourcetype Iter = <&'a T as IntoParallelIterator>::Iter
type Iter = <&'a T as IntoParallelIterator>::Iter
The parallel iterator type that will be created.
Sourcefn into_par_iter(self) -> <&'a ViewMut<T, G> as IntoParallelIterator>::Iter
fn into_par_iter(self) -> <&'a ViewMut<T, G> as IntoParallelIterator>::Iter
Converts
self into a parallel iterator. Read moreSourceimpl<'a, T, G> IntoParallelIterator for &'a mut ViewMut<T, G>
impl<'a, T, G> IntoParallelIterator for &'a mut ViewMut<T, G>
Sourcetype Item = <&'a mut T as IntoParallelIterator>::Item
type Item = <&'a mut T as IntoParallelIterator>::Item
The type of item that the parallel iterator will produce.
Sourcetype Iter = <&'a mut T as IntoParallelIterator>::Iter
type Iter = <&'a mut T as IntoParallelIterator>::Iter
The parallel iterator type that will be created.
Sourcefn into_par_iter(self) -> <&'a mut ViewMut<T, G> as IntoParallelIterator>::Iter
fn into_par_iter(self) -> <&'a mut ViewMut<T, G> as IntoParallelIterator>::Iter
Converts
self into a parallel iterator. Read moreAuto Trait Implementations
impl<T, G> Freeze for ViewMut<T, G>
impl<T, G = SomeDefault> !RefUnwindSafe for ViewMut<T, G>
impl<T, G> Send for ViewMut<T, G>
impl<T, G> Sync for ViewMut<T, G>
impl<T, G> Unpin for ViewMut<T, G>
impl<T, G = SomeDefault> !UnwindSafe for ViewMut<T, G>